export type MaybeArray<T> = T | T[];
export type ElementPropsValue = undefined | boolean | string | number | any[] | Record<string, any> | Set<any> | Map<any, any>;
export type ElementProps = {
    [key: string]: ElementPropsValue;
};
export type RenderableElementFunction<Props extends ElementProps> = (props: Props, children: RenderableElement[]) => HtmlMethodResult;
export type SimpleRenderableElementFunction = RenderableElementFunction<ElementProps>;
export type StringRenderableElement<Props extends ElementProps> = {
    type: string;
    props: Props;
    children: RenderableElement[];
};
export type BasicRenderableElement<Props extends ElementProps> = {
    type: string | RenderableElementFunction<Props>;
    props: Props;
    children: RenderableElement[];
    skipStringEscape?: boolean;
};
export type RenderableElement = string | number | BasicRenderableElement<any>;
export type HtmlMethodResult = MaybeArray<BasicRenderableElement<ElementProps> | string>;
export type IterableIteratorMaybeAsync<T> = T[] | IterableIterator<T> | AsyncIterableIterator<T>;
export function generatorToString(generator: IterableIteratorMaybeAsync<string>): Promise<string>;
export function html(strings: TemplateStringsArray, ...values: (ElementPropsValue | ElementProps | RenderableElementFunction<any> | RenderableElement | RenderableElement[])[]): HtmlMethodResult;
export function h<T extends ElementProps>(type: string | RenderableElementFunction<T>, props: T, ...children: RenderableElement[]): BasicRenderableElement<T>;
export function rawHtml(strings: TemplateStringsArray | string, ...values: (string | number)[]): BasicRenderableElement<{}>;
export function render(item: HtmlMethodResult): AsyncIterableIterator<string>;
export function renderToString(item: HtmlMethodResult): Promise<string>;
//# sourceMappingURL=index.d.ts.map